Learn R Programming

STREAK (version 1.0.0)

receptorGeneSetConstruction: Gene sets weights membership matrix construction for receptor abundance estimation.

Description

Computes \(n x h\) gene sets weights membership matrix using associations learned between log-normalized and reduced rank reconstructed (RRR) \(m x n\) scRNA-seq training data and \(m x h\) CITE-seq ADT training counts normalized using the centered log ratio (CLR) transformation. scRNA-seq counts are normalized and RRR using the SPECK::randomizedRRR() function while CITE-seq counts are normalized using the Seurat::NormalizeData() function with the normalization.method parameter set to CLR. Spearman rank correlations are computed between the normalized CITE-seq data and the normalized and RRR scRNA-seq data.

Usage

receptorGeneSetConstruction(
  train.rnaseq,
  train.citeseq,
  rank.range.end = 100,
  min.consec.diff = 0.01,
  rep.consec.diff = 2,
  manual.rank = NULL,
  seed.rsvd = 1
)

Value

  • receptor.geneset.matrix - A \(n x h\) gene sets weights membership matrix where a column \(i\) from \(h\) corresponds to the weights for \(n\) genes from the scRNA-seq matrix trained against the corresponding CITE-seq ADT transcript \(h\).

Arguments

train.rnaseq

\(m x n\) scRNA-seq counts matrix for \(m\) cells and \(n\) genes.

train.citeseq

\(m x h\) CITE-seq ADT counts matrix for \(m\) cells (same cells as the train.rnaseq matrix) and \(h\) cell-surface proteins.

rank.range.end

See documentation for the randomizedRRR function from the SPECK package.

min.consec.diff

See documentation for the randomizedRRR function from the SPECK package.

rep.consec.diff

See documentation for the randomizedRRR function from the SPECK package.

manual.rank

See documentation for the randomizedRRR function from the SPECK package.

seed.rsvd

See documentation for the randomizedRRR function from the SPECK package.

Examples

Run this code
data("train.malt.rna.mat")
data("train.malt.adt.mat")
receptor.geneset.matrix.out <- receptorGeneSetConstruction(train.rnaseq =
                                         train.malt.rna.mat[1:100,1:80],
                                         train.citeseq =
                                         train.malt.adt.mat[1:100,1:2],
                                         rank.range.end = 70,
                                         min.consec.diff = 0.01,
                                         rep.consec.diff = 2,
                                         manual.rank = NULL, seed.rsvd = 1)
dim(receptor.geneset.matrix.out)
head(receptor.geneset.matrix.out)

Run the code above in your browser using DataLab